==> elektra-0.9.7.tar.gz: elektra-0.9.7/src/plugins/toml/toml/key_names_empty.h <==
// clang-format off
ksNew (16,
	keyNew (PREFIX "/%",
		KEY_VALUE, "discouraged, but valid",
		KEY_META, "type", "string",
		KEY_META, "order", "0",
	KEY_END),
	keyNew (PREFIX "/%/%",
		KEY_VALUE, "discouraged, but valid",
		KEY_META, "type", "string",
		KEY_META, "order", "1",
	KEY_END),
	keyNew (PREFIX "/%/weird/%/very_weird/%",
		KEY_VALUE, "absolutely",
		KEY_META, "type", "string",
		KEY_META, "order", "2",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline",
		KEY_META, "tomltype", "inlinetable",
		KEY_META, "order", "3",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline/%",
		KEY_VALUE, "ouch",
		KEY_META, "type", "string",
		KEY_META, "order", "4",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline/a/%",
		KEY_VALUE, "oh no",
		KEY_META, "type", "string",
		KEY_META, "order", "5",
	KEY_END),

	keyNew (PREFIX "/a/%",
		KEY_META, "tomltype", "simpletable",
		KEY_META, "order", "6",
	KEY_END),
	keyNew (PREFIX "/a/%/having_a_discouraged_super_table",
		KEY_VALUE, "1",
		KEY_META, "type", "long_long",
		KEY_META, "order", "7",
	KEY_END),

	keyNew (PREFIX "/1337/%/%/weird_table/%",
		KEY_META, "tomltype", "simpletable",
		KEY_META, "order", "8",
	KEY_END),
	keyNew (PREFIX "/1337/%/%/weird_table/%/horrible_super_table",
		KEY_VALUE, "yes",
		KEY_META, "type", "string",
		KEY_META, "order", "9",
	KEY_END),

	keyNew (PREFIX "/horrible_table_array/%/%/pew",
		KEY_META, "tomltype", "tablearray",
		KEY_META, "order", "10",
		KEY_META, "array", "#2",
	KEY_END),

	keyNew (PREFIX "/horrible_table_array/%/%/pew/#0/brutal",
		KEY_VALUE, "1",
		KEY_META, "type", "long_long",
		KEY_META, "order", "11",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#1/brutal",
		KEY_VALUE, "2",
		KEY_META, "type", "long_long",
		KEY_META, "order", "12",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#2/brutal",
		KEY_VALUE, "3",
		KEY_META, "type", "long_long",
		KEY_META, "order", "13",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#2/%",
		KEY_VALUE, "4",
		KEY_META, "type", "long_long",
		KEY_META, "order", "14",
	KEY_END),
KS_END)

==> elektra-0.9.11.tar.gz: elektra-0.9.11/src/plugins/toml/toml/key_names_empty.h <==
// clang-format off
ksNew (16,
	keyNew (PREFIX "/%",
		KEY_VALUE, "discouraged, but valid",
		KEY_META, "tomltype", "string_basic",
		KEY_META, "type", "string",
		KEY_META, "order", "0",
	KEY_END),
	keyNew (PREFIX "/%/%",
		KEY_VALUE, "discouraged, but valid",
		KEY_META, "tomltype", "string_basic",
		KEY_META, "type", "string",
		KEY_META, "order", "1",
	KEY_END),
	keyNew (PREFIX "/%/weird/%/very_weird/%",
		KEY_VALUE, "absolutely",
		KEY_META, "tomltype", "string_basic",
		KEY_META, "type", "string",
		KEY_META, "order", "2",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline",
		KEY_META, "tomltype", "inlinetable",
		KEY_META, "order", "3",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline/%",
		KEY_VALUE, "ouch",
		KEY_META, "tomltype", "string_basic",
		KEY_META, "type", "string",
		KEY_META, "order", "4",
	KEY_END),

	keyNew (PREFIX "/discouraged/%/inline/a/%",
		KEY_VALUE, "oh no",
		KEY_META, "tomltype", "string_basic",
		KEY_META, "type", "string",
		KEY_META, "order", "5",
	KEY_END),

	keyNew (PREFIX "/a/%",
		KEY_META, "tomltype", "simpletable",
		KEY_META, "order", "6",
	KEY_END),
	keyNew (PREFIX "/a/%/having_a_discouraged_super_table",
		KEY_VALUE, "1",
		KEY_META, "type", "long_long",
		KEY_META, "order", "7",
	KEY_END),

	keyNew (PREFIX "/1337/%/%/weird_table/%",
		KEY_META, "tomltype", "simpletable",
		KEY_META, "order", "8",
	KEY_END),
	keyNew (PREFIX "/1337/%/%/weird_table/%/horrible_super_table",
		KEY_VALUE, "yes",
		KEY_META, "tomltype", "string_literal",
		KEY_META, "type", "string",
		KEY_META, "order", "9",
	KEY_END),

	keyNew (PREFIX "/horrible_table_array/%/%/pew",
		KEY_META, "tomltype", "tablearray",
		KEY_META, "order", "10",
		KEY_META, "array", "#2",
	KEY_END),

	keyNew (PREFIX "/horrible_table_array/%/%/pew/#0/brutal",
		KEY_VALUE, "1",
		KEY_META, "type", "long_long",
		KEY_META, "order", "11",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#1/brutal",
		KEY_VALUE, "2",
		KEY_META, "type", "long_long",
		KEY_META, "order", "12",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#2/brutal",
		KEY_VALUE, "3",
		KEY_META, "type", "long_long",
		KEY_META, "order", "13",
	KEY_END),
	keyNew (PREFIX "/horrible_table_array/%/%/pew/#2/%",
		KEY_VALUE, "4",
		KEY_META, "type", "long_long",
		KEY_META, "order", "14",
	KEY_END),
KS_END)
